@@ -482,7 +482,42 @@ class BucketDeployment(
         :param website_redirect_location: System-defined x-amz-website-redirect-location metadata to be set on all objects in the deployment. Default: - No website redirection.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(BucketDeployment.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                destination_bucket: aws_cdk.aws_s3.IBucket,
+                sources: typing.Sequence["ISource"],
+                access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
+                cache_control: typing.Optional[typing.Sequence["CacheControl"]] = None,
+                content_disposition: typing.Optional[builtins.str] = None,
+                content_encoding: typing.Optional[builtins.str] = None,
+                content_language: typing.Optional[builtins.str] = None,
+                content_type: typing.Optional[builtins.str] = None,
+                destination_key_prefix: typing.Optional[builtins.str] = None,
+                distribution: typing.Optional[aws_cdk.aws_cloudfront.IDistribution] = None,
+                distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+                ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
+                exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+                expires: typing.Optional[aws_cdk.core.Expiration] = None,
+                include: typing.Optional[typing.Sequence[builtins.str]] = None,
+                log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
+                memory_limit: typing.Optional[jsii.Number] = None,
+                metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[str, typing.Any]]] = None,
+                prune: typing.Optional[builtins.bool] = None,
+                retain_on_delete: typing.Optional[builtins.bool] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                server_side_encryption: typing.Optional["ServerSideEncryption"] = None,
+                server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
+                server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
+                storage_class: typing.Optional["StorageClass"] = None,
+                use_efs: typing.Optional[builtins.bool] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+                website_redirect_location: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BucketDeploymentProps(
@@ -656,7 +691,40 @@ class BucketDeploymentProps:
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
         if __debug__:
-            type_hints = typing.get_type_hints(BucketDeploymentProps.__init__)
+            def stub(
+                *,
+                destination_bucket: aws_cdk.aws_s3.IBucket,
+                sources: typing.Sequence["ISource"],
+                access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
+                cache_control: typing.Optional[typing.Sequence["CacheControl"]] = None,
+                content_disposition: typing.Optional[builtins.str] = None,
+                content_encoding: typing.Optional[builtins.str] = None,
+                content_language: typing.Optional[builtins.str] = None,
+                content_type: typing.Optional[builtins.str] = None,
+                destination_key_prefix: typing.Optional[builtins.str] = None,
+                distribution: typing.Optional[aws_cdk.aws_cloudfront.IDistribution] = None,
+                distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+                ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
+                exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+                expires: typing.Optional[aws_cdk.core.Expiration] = None,
+                include: typing.Optional[typing.Sequence[builtins.str]] = None,
+                log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
+                memory_limit: typing.Optional[jsii.Number] = None,
+                metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[str, typing.Any]]] = None,
+                prune: typing.Optional[builtins.bool] = None,
+                retain_on_delete: typing.Optional[builtins.bool] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                server_side_encryption: typing.Optional["ServerSideEncryption"] = None,
+                server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
+                server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
+                storage_class: typing.Optional["StorageClass"] = None,
+                use_efs: typing.Optional[builtins.bool] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+                website_redirect_location: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument destination_bucket", value=destination_bucket, expected_type=type_hints["destination_bucket"])
             check_type(argname="argument sources", value=sources, expected_type=type_hints["sources"])
             check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
@@ -1115,7 +1183,9 @@ class CacheControl(
         :param s: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CacheControl.from_string)
+            def stub(s: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument s", value=s, expected_type=type_hints["s"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "fromString", [s]))
 
@@ -1127,7 +1197,9 @@ class CacheControl(
         :param t: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CacheControl.max_age)
+            def stub(t: aws_cdk.core.Duration) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "maxAge", [t]))
 
@@ -1175,7 +1247,9 @@ class CacheControl(
         :param t: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CacheControl.s_max_age)
+            def stub(t: aws_cdk.core.Duration) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "sMaxAge", [t]))
 
@@ -1213,7 +1287,9 @@ class DeploymentSourceContext:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DeploymentSourceContext.__init__)
+            def stub(*, handler_role: aws_cdk.aws_iam.IRole) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument handler_role", value=handler_role, expected_type=type_hints["handler_role"])
         self._values: typing.Dict[str, typing.Any] = {
             "handler_role": handler_role,
@@ -1269,7 +1345,9 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Expires.after)
+            def stub(t: aws_cdk.core.Duration) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("Expires", jsii.sinvoke(cls, "after", [t]))
 
@@ -1283,7 +1361,9 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Expires.at_date)
+            def stub(d: datetime.datetime) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument d", value=d, expected_type=type_hints["d"])
         return typing.cast("Expires", jsii.sinvoke(cls, "atDate", [d]))
 
@@ -1297,7 +1377,9 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Expires.at_timestamp)
+            def stub(t: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("Expires", jsii.sinvoke(cls, "atTimestamp", [t]))
 
@@ -1311,7 +1393,9 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Expires.from_string)
+            def stub(s: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument s", value=s, expected_type=type_hints["s"])
         return typing.cast("Expires", jsii.sinvoke(cls, "fromString", [s]))
 
@@ -1362,7 +1446,13 @@ class _ISourceProxy:
         :param handler_role: The role for the handler.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ISource.bind)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                *,
+                handler_role: aws_cdk.aws_iam.IRole,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         context = DeploymentSourceContext(handler_role=handler_role)
 
@@ -1473,7 +1563,21 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         :param bundling: Bundle the asset by executing a command in a Docker container or a custom bundling provider. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.asset)
+            def stub(
+                path: builtins.str,
+                *,
+                readers: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IGrantable]] = None,
+                source_hash: typing.Optional[builtins.str] = None,
+                exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+                follow: typing.Optional[aws_cdk.assets.FollowMode] = None,
+                ignore_mode: typing.Optional[aws_cdk.core.IgnoreMode] = None,
+                follow_symlinks: typing.Optional[aws_cdk.core.SymlinkFollowMode] = None,
+                asset_hash: typing.Optional[builtins.str] = None,
+                asset_hash_type: typing.Optional[aws_cdk.core.AssetHashType] = None,
+                bundling: typing.Optional[typing.Union[aws_cdk.core.BundlingOptions, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         options = aws_cdk.aws_s3_assets.AssetOptions(
             readers=readers,
@@ -1504,7 +1608,12 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         :param zip_object_key: The S3 object key of the zip file with contents.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.bucket)
+            def stub(
+                bucket: aws_cdk.aws_s3.IBucket,
+                zip_object_key: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
             check_type(argname="argument zip_object_key", value=zip_object_key, expected_type=type_hints["zip_object_key"])
         return typing.cast(ISource, jsii.sinvoke(cls, "bucket", [bucket, zip_object_key]))
@@ -1524,7 +1633,9 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         :param data: The data to be stored in the object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.data)
+            def stub(object_key: builtins.str, data: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
             check_type(argname="argument data", value=data, expected_type=type_hints["data"])
         return typing.cast(ISource, jsii.sinvoke(cls, "data", [object_key, data]))
@@ -1542,7 +1653,9 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         :param obj: A JSON object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.json_data)
+            def stub(object_key: builtins.str, obj: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
             check_type(argname="argument obj", value=obj, expected_type=type_hints["obj"])
         return typing.cast(ISource, jsii.sinvoke(cls, "jsonData", [object_key, obj]))
@@ -1594,7 +1707,14 @@ class SourceConfig:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SourceConfig.__init__)
+            def stub(
+                *,
+                bucket: aws_cdk.aws_s3.IBucket,
+                zip_object_key: builtins.str,
+                markers: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
             check_type(argname="argument zip_object_key", value=zip_object_key, expected_type=type_hints["zip_object_key"])
             check_type(argname="argument markers", value=markers, expected_type=type_hints["markers"])
